summaryrefslogtreecommitdiffhomepage
path: root/runsc/cli/main.go
diff options
context:
space:
mode:
authorgVisor bot <gvisor-bot@google.com>2021-04-19 23:52:48 +0000
committergVisor bot <gvisor-bot@google.com>2021-04-19 23:52:48 +0000
commit971b7fe85715e357907cdb576af52c48a22eaa99 (patch)
treea0fe1d30b267f863a44078adfcd3084d460f67d7 /runsc/cli/main.go
parentae3938ad39944b0d67ba0a6aba8efad9307b9868 (diff)
parent20b1c3c632277bd64eac4d0442bda9695f184fc9 (diff)
Merge release-20210412.0-34-g20b1c3c63 (automated)
Diffstat (limited to 'runsc/cli/main.go')
-rw-r--r--runsc/cli/main.go4
1 files changed, 3 insertions, 1 deletions
diff --git a/runsc/cli/main.go b/runsc/cli/main.go
index 79eb85cff..76184cd9c 100644
--- a/runsc/cli/main.go
+++ b/runsc/cli/main.go
@@ -30,6 +30,7 @@ import (
"gvisor.dev/gvisor/pkg/coverage"
"gvisor.dev/gvisor/pkg/log"
"gvisor.dev/gvisor/pkg/refs"
+ "gvisor.dev/gvisor/pkg/refsvfs2"
"gvisor.dev/gvisor/pkg/sentry/platform"
"gvisor.dev/gvisor/runsc/cmd"
"gvisor.dev/gvisor/runsc/config"
@@ -240,7 +241,8 @@ func Main(version string) {
// Call the subcommand and pass in the configuration.
var ws unix.WaitStatus
subcmdCode := subcommands.Execute(context.Background(), conf, &ws)
- // Write coverage report before os.Exit().
+ // Check for leaks and write coverage report before os.Exit().
+ refsvfs2.DoLeakCheck()
coverage.Report()
if subcmdCode == subcommands.ExitSuccess {
log.Infof("Exiting with status: %v", ws)